@@ -92,243 +92,243 @@ fn main() {
     let parsers = vec![
         TreeSitterParser {
             name: "tree-sitter-bash",
-            src_dir: "vendor/tree-sitter-bash-src",
+            src_dir: "vendored_parsers/tree-sitter-bash-src",
             extra_files: vec!["scanner.cc"],
         },
         TreeSitterParser {
             name: "tree-sitter-c",
-            src_dir: "vendor/tree-sitter-c-src",
+            src_dir: "vendored_parsers/tree-sitter-c-src",
             extra_files: vec![],
         },
         TreeSitterParser {
             name: "tree-sitter-cpp",
-            src_dir: "vendor/tree-sitter-cpp-src",
+            src_dir: "vendored_parsers/tree-sitter-cpp-src",
             extra_files: vec!["scanner.cc"],
         },
         TreeSitterParser {
             name: "tree-sitter-c-sharp",
-            src_dir: "vendor/tree-sitter-c-sharp-src",
+            src_dir: "vendored_parsers/tree-sitter-c-sharp-src",
             extra_files: vec!["scanner.c"],
         },
         TreeSitterParser {
             name: "tree-sitter-clojure",
-            src_dir: "vendor/tree-sitter-clojure-src",
+            src_dir: "vendored_parsers/tree-sitter-clojure-src",
             extra_files: vec![],
         },
         TreeSitterParser {
             name: "tree-sitter-cmake",
-            src_dir: "vendor/tree-sitter-cmake-src",
+            src_dir: "vendored_parsers/tree-sitter-cmake-src",
             extra_files: vec!["scanner.cc"],
         },
         TreeSitterParser {
             name: "tree-sitter-commonlisp",
-            src_dir: "vendor/tree-sitter-commonlisp-src",
+            src_dir: "vendored_parsers/tree-sitter-commonlisp-src",
             extra_files: vec![],
         },
         TreeSitterParser {
             name: "tree-sitter-css",
-            src_dir: "vendor/tree-sitter-css-src",
+            src_dir: "vendored_parsers/tree-sitter-css-src",
             extra_files: vec!["scanner.c"],
         },
         TreeSitterParser {
             name: "tree-sitter-dart",
-            src_dir: "vendor/tree-sitter-dart-src",
+            src_dir: "vendored_parsers/tree-sitter-dart-src",
             extra_files: vec!["scanner.c"],
         },
         TreeSitterParser {
             name: "tree-sitter-elisp",
-            src_dir: "vendor/tree-sitter-elisp-src",
+            src_dir: "vendored_parsers/tree-sitter-elisp-src",
             extra_files: vec![],
         },
         TreeSitterParser {
             name: "tree-sitter-elixir",
-            src_dir: "vendor/tree-sitter-elixir-src",
+            src_dir: "vendored_parsers/tree-sitter-elixir-src",
             extra_files: vec!["scanner.cc"],
         },
         TreeSitterParser {
             name: "tree-sitter-elm",
-            src_dir: "vendor/tree-sitter-elm-src",
+            src_dir: "vendored_parsers/tree-sitter-elm-src",
             extra_files: vec!["scanner.cc"],
         },
         TreeSitterParser {
             name: "tree-sitter-elvish",
-            src_dir: "vendor/tree-sitter-elvish-src",
+            src_dir: "vendored_parsers/tree-sitter-elvish-src",
             extra_files: vec![],
         },
         TreeSitterParser {
             name: "tree-sitter-erlang",
-            src_dir: "vendor/tree-sitter-erlang-src",
+            src_dir: "vendored_parsers/tree-sitter-erlang-src",
             extra_files: vec![],
         },
         TreeSitterParser {
             name: "tree-sitter-gleam",
-            src_dir: "vendor/tree-sitter-gleam-src",
+            src_dir: "vendored_parsers/tree-sitter-gleam-src",
             extra_files: vec!["scanner.c"],
         },
         TreeSitterParser {
             name: "tree-sitter-go",
-            src_dir: "vendor/tree-sitter-go-src",
+            src_dir: "vendored_parsers/tree-sitter-go-src",
             extra_files: vec![],
         },
         TreeSitterParser {
             name: "tree-sitter-hack",
-            src_dir: "vendor/tree-sitter-hack-src",
+            src_dir: "vendored_parsers/tree-sitter-hack-src",
             extra_files: vec!["scanner.cc"],
         },
         TreeSitterParser {
             name: "tree-sitter-hare",
-            src_dir: "vendor/tree-sitter-hare-src",
+            src_dir: "vendored_parsers/tree-sitter-hare-src",
             extra_files: vec![],
         },
         TreeSitterParser {
             name: "tree-sitter-haskell",
-            src_dir: "vendor/tree-sitter-haskell-src",
+            src_dir: "vendored_parsers/tree-sitter-haskell-src",
             extra_files: vec!["scanner.c"],
         },
         TreeSitterParser {
             name: "tree-sitter-hcl",
-            src_dir: "vendor/tree-sitter-hcl-src",
+            src_dir: "vendored_parsers/tree-sitter-hcl-src",
             extra_files: vec!["scanner.cc"],
         },
         TreeSitterParser {
             name: "tree-sitter-html",
-            src_dir: "vendor/tree-sitter-html-src",
+            src_dir: "vendored_parsers/tree-sitter-html-src",
             extra_files: vec!["scanner.cc"],
         },
         TreeSitterParser {
             name: "tree-sitter-janet-simple",
-            src_dir: "vendor/tree-sitter-janet-simple-src",
+            src_dir: "vendored_parsers/tree-sitter-janet-simple-src",
             extra_files: vec!["scanner.c"],
         },
         TreeSitterParser {
             name: "tree-sitter-java",
-            src_dir: "vendor/tree-sitter-java-src",
+            src_dir: "vendored_parsers/tree-sitter-java-src",
             extra_files: vec![],
         },
         TreeSitterParser {
             name: "tree-sitter-javascript",
-            src_dir: "vendor/tree-sitter-javascript-src",
+            src_dir: "vendored_parsers/tree-sitter-javascript-src",
             extra_files: vec!["scanner.c"],
         },
         TreeSitterParser {
             name: "tree-sitter-json",
-            src_dir: "vendor/tree-sitter-json-src",
+            src_dir: "vendored_parsers/tree-sitter-json-src",
             extra_files: vec![],
         },
         TreeSitterParser {
             name: "tree-sitter-julia",
-            src_dir: "vendor/tree-sitter-julia-src",
+            src_dir: "vendored_parsers/tree-sitter-julia-src",
             extra_files: vec!["scanner.c"],
         },
         TreeSitterParser {
             name: "tree-sitter-kotlin",
-            src_dir: "vendor/tree-sitter-kotlin-src",
+            src_dir: "vendored_parsers/tree-sitter-kotlin-src",
             extra_files: vec!["scanner.c"],
         },
         TreeSitterParser {
             name: "tree-sitter-lua",
-            src_dir: "vendor/tree-sitter-lua-src",
+            src_dir: "vendored_parsers/tree-sitter-lua-src",
             extra_files: vec!["scanner.cc"],
         },
         TreeSitterParser {
             name: "tree-sitter-make",
-            src_dir: "vendor/tree-sitter-make-src",
+            src_dir: "vendored_parsers/tree-sitter-make-src",
             extra_files: vec![],
         },
         TreeSitterParser {
             name: "tree-sitter-nix",
-            src_dir: "vendor/tree-sitter-nix-src",
+            src_dir: "vendored_parsers/tree-sitter-nix-src",
             extra_files: vec!["scanner.c"],
         },
         TreeSitterParser {
             name: "tree-sitter-ocaml",
-            src_dir: "vendor/tree-sitter-ocaml-src/ocaml/src",
+            src_dir: "vendored_parsers/tree-sitter-ocaml-src/ocaml/src",
             extra_files: vec!["scanner.cc"],
         },
         TreeSitterParser {
             name: "tree-sitter-ocaml-interface",
-            src_dir: "vendor/tree-sitter-ocaml-src/interface/src",
+            src_dir: "vendored_parsers/tree-sitter-ocaml-src/interface/src",
             extra_files: vec!["scanner.cc"],
         },
         TreeSitterParser {
             name: "tree-sitter-pascal",
-            src_dir: "vendor/tree-sitter-pascal-src",
+            src_dir: "vendored_parsers/tree-sitter-pascal-src",
             extra_files: vec![],
         },
         TreeSitterParser {
             name: "tree-sitter-perl",
-            src_dir: "vendor/tree-sitter-perl-src",
+            src_dir: "vendored_parsers/tree-sitter-perl-src",
             extra_files: vec!["scanner.cc"],
         },
         TreeSitterParser {
             name: "tree-sitter-php",
-            src_dir: "vendor/tree-sitter-php-src",
+            src_dir: "vendored_parsers/tree-sitter-php-src",
             extra_files: vec!["scanner.cc"],
         },
         TreeSitterParser {
             name: "tree-sitter-python",
-            src_dir: "vendor/tree-sitter-python-src",
+            src_dir: "vendored_parsers/tree-sitter-python-src",
             extra_files: vec!["scanner.cc"],
         },
         TreeSitterParser {
             name: "tree-sitter-qmljs",
-            src_dir: "vendor/tree-sitter-qmljs-src",
+            src_dir: "vendored_parsers/tree-sitter-qmljs-src",
             extra_files: vec!["scanner.c"],
         },
         TreeSitterParser {
             name: "tree-sitter-ruby",
-            src_dir: "vendor/tree-sitter-ruby-src",
+            src_dir: "vendored_parsers/tree-sitter-ruby-src",
             extra_files: vec!["scanner.cc"],
         },
         TreeSitterParser {
             name: "tree-sitter-rust",
-            src_dir: "vendor/tree-sitter-rust-src",
+            src_dir: "vendored_parsers/tree-sitter-rust-src",
             extra_files: vec!["scanner.c"],
         },
         TreeSitterParser {
             name: "tree-sitter-scala",
-            src_dir: "vendor/tree-sitter-scala-src",
+            src_dir: "vendored_parsers/tree-sitter-scala-src",
             extra_files: vec!["scanner.c"],
         },
         TreeSitterParser {
             name: "tree-sitter-sql",
-            src_dir: "vendor/tree-sitter-sql-src",
+            src_dir: "vendored_parsers/tree-sitter-sql-src",
             extra_files: vec!["scanner.cc"],
         },
         TreeSitterParser {
             name: "tree-sitter-swift",
-            src_dir: "vendor/tree-sitter-swift-src",
+            src_dir: "vendored_parsers/tree-sitter-swift-src",
             extra_files: vec!["scanner.c"],
         },
         TreeSitterParser {
             name: "tree-sitter-toml",
-            src_dir: "vendor/tree-sitter-toml-src",
+            src_dir: "vendored_parsers/tree-sitter-toml-src",
             extra_files: vec!["scanner.c"],
         },
         TreeSitterParser {
             name: "tree-sitter-tsx",
-            src_dir: "vendor/tree-sitter-typescript-src/tsx/src",
+            src_dir: "vendored_parsers/tree-sitter-typescript-src/tsx/src",
             extra_files: vec!["scanner.c"],
         },
         TreeSitterParser {
             name: "tree-sitter-typescript",
-            src_dir: "vendor/tree-sitter-typescript-src/typescript/src",
+            src_dir: "vendored_parsers/tree-sitter-typescript-src/typescript/src",
             extra_files: vec!["scanner.c"],
         },
         TreeSitterParser {
             name: "tree-sitter-yaml",
-            src_dir: "vendor/tree-sitter-yaml-src",
+            src_dir: "vendored_parsers/tree-sitter-yaml-src",
             extra_files: vec!["scanner.cc"],
         },
         TreeSitterParser {
             name: "tree-sitter-zig",
-            src_dir: "vendor/tree-sitter-zig-src",
+            src_dir: "vendored_parsers/tree-sitter-zig-src",
             extra_files: vec![],
         },
     ];
 
-    // Only rerun if relevant files in the vendor/ directory change.
-    println!("cargo:rerun-if-changed=vendor/highlights");
+    // Only rerun if relevant files in the vendored_parsers/ directory change.
+    println!("cargo:rerun-if-changed=vendored_parsers/highlights");
     for parser in &parsers {
         println!("cargo:rerun-if-changed={}", parser.src_dir);
     }
