@@ -105,7 +105,7 @@ fn main() {
             match language {
                 Some(lang) => {
                     let ts_lang = tsp::from_language(lang);
-                    let tree = tsp::parse_to_tree(&src, &ts_lang);
+                    let tree = tsp::to_tree(&src, &ts_lang);
                     tsp::print_tree(&src, &tree);
                 }
                 None => {
@@ -126,7 +126,8 @@ fn main() {
                 Some(lang) => {
                     let ts_lang = tsp::from_language(lang);
                     let arena = Arena::new();
-                    let ast = tsp::parse(&arena, &src, &ts_lang);
+                    // TODO: respect ignore_comments
+                    let ast = tsp::parse(&arena, &src, &ts_lang, false);
                     init_all_info(&ast, &[]);
                     println!("{:#?}", ast);
                 }
@@ -295,8 +296,8 @@ fn diff_file_content(
             return DiffResult {
                 lhs_display_path: lhs_display_path.into(),
                 rhs_display_path: rhs_display_path.into(),
-                language: None,
-                detected_language: None,
+                display_language: None,
+                language_used: None,
                 lhs_src: FileContent::Binary,
                 rhs_src: FileContent::Binary,
                 lhs_positions: vec![],
@@ -325,7 +326,7 @@ fn diff_file_content(
         FileArgument::DevNull => (&lhs_src, Path::new(&lhs_display_path)),
     };
 
-    let mut language = language_override.or_else(|| guess(guess_path, guess_src));
+    let language = language_override.or_else(|| guess(guess_path, guess_src));
     let lang_config = language.map(tsp::from_language);
 
     if lhs_bytes == rhs_bytes {
@@ -334,8 +335,8 @@ fn diff_file_content(
         return DiffResult {
             lhs_display_path: lhs_display_path.into(),
             rhs_display_path: rhs_display_path.into(),
-            language: language.map(|l| language_name(l).into()),
-            detected_language: language,
+            display_language: language.map(|l| language_name(l).into()),
+            language_used: language,
             lhs_src: FileContent::Text("".into()),
             rhs_src: FileContent::Text("".into()),
             lhs_positions: vec![],
@@ -346,6 +347,7 @@ fn diff_file_content(
         };
     }
 
+    let mut language_used = None;
     let (lang_name, lhs_positions, rhs_positions) = match lang_config {
         _ if lhs_bytes.len() > diff_options.byte_limit
             || rhs_bytes.len() > diff_options.byte_limit =>
@@ -359,9 +361,24 @@ fn diff_file_content(
             )
         }
         Some(ts_lang) => {
+            let lhs_tree = tsp::to_tree(&lhs_src, &ts_lang);
+            let rhs_tree = tsp::to_tree(&rhs_src, &ts_lang);
+
             let arena = Arena::new();
-            let lhs = tsp::parse(&arena, &lhs_src, &ts_lang);
-            let rhs = tsp::parse(&arena, &rhs_src, &ts_lang);
+            let lhs = tsp::to_syntax(
+                &lhs_tree,
+                &lhs_src,
+                &arena,
+                &ts_lang,
+                diff_options.ignore_comments,
+            );
+            let rhs = tsp::to_syntax(
+                &rhs_tree,
+                &rhs_src,
+                &arena,
+                &ts_lang,
+                diff_options.ignore_comments,
+            );
 
             init_all_info(&lhs, &rhs);
 
@@ -369,11 +386,12 @@ fn diff_file_content(
                 let lang_name = language.map(|l| language_name(l).into());
                 let has_syntactic_changes = lhs != rhs;
 
+                language_used = language;
                 return DiffResult {
                     lhs_display_path: lhs_display_path.into(),
                     rhs_display_path: rhs_display_path.into(),
-                    language: lang_name,
-                    detected_language: language,
+                    display_language: lang_name,
+                    language_used,
                     lhs_src: FileContent::Text(lhs_src),
                     rhs_src: FileContent::Text(rhs_src),
                     lhs_positions: vec![],
@@ -414,21 +432,30 @@ fn diff_file_content(
             if exceeded_graph_limit {
                 let lhs_positions = line_parser::change_positions(&lhs_src, &rhs_src);
                 let rhs_positions = line_parser::change_positions(&rhs_src, &lhs_src);
-                language = None;
                 (
                     Some("Text (exceeded DFT_GRAPH_LIMIT)".into()),
                     lhs_positions,
                     rhs_positions,
                 )
             } else {
+                language_used = language;
                 // TODO: Make this .expect() unnecessary.
                 let language =
                     language.expect("If we had a ts_lang, we must have guessed the language");
                 fix_all_sliders(language, &lhs, &mut change_map);
                 fix_all_sliders(language, &rhs, &mut change_map);
 
-                let lhs_positions = syntax::change_positions(&lhs, &change_map);
-                let rhs_positions = syntax::change_positions(&rhs, &change_map);
+                let mut lhs_positions = syntax::change_positions(&lhs, &change_map);
+                let mut rhs_positions = syntax::change_positions(&rhs, &change_map);
+
+                if diff_options.ignore_comments {
+                    let lhs_comments = tsp::comment_positions(&lhs_tree, &lhs_src, &ts_lang);
+                    lhs_positions.extend(lhs_comments);
+
+                    let rhs_comments = tsp::comment_positions(&rhs_tree, &rhs_src, &ts_lang);
+                    rhs_positions.extend(rhs_comments);
+                }
+
                 (
                     Some(language_name(language).into()),
                     lhs_positions,
@@ -460,8 +487,8 @@ fn diff_file_content(
     DiffResult {
         lhs_display_path: lhs_display_path.into(),
         rhs_display_path: rhs_display_path.into(),
-        language: lang_name,
-        detected_language: language,
+        display_language: lang_name,
+        language_used,
         lhs_src: FileContent::Text(lhs_src),
         rhs_src: FileContent::Text(rhs_src),
         lhs_positions,
@@ -517,7 +544,10 @@ fn print_diff_result(display_options: &DisplayOptions, summary: &DiffResult) {
         (FileContent::Text(lhs_src), FileContent::Text(rhs_src)) => {
             let hunks = &summary.hunks;
 
-            let lang_name = summary.language.clone().unwrap_or_else(|| "Text".into());
+            let display_language = summary
+                .display_language
+                .clone()
+                .unwrap_or_else(|| "Text".into());
             if !summary.has_syntactic_changes {
                 if display_options.print_unchanged {
                     println!(
@@ -527,12 +557,12 @@ fn print_diff_result(display_options: &DisplayOptions, summary: &DiffResult) {
                             &summary.rhs_display_path,
                             1,
                             1,
-                            &lang_name,
+                            &display_language,
                             display_options
                         )
                     );
-                    if lang_name == "Text" || summary.lhs_src == summary.rhs_src {
-                        // TODO: there are other Text names now, so
+                    if display_language == "Text" || summary.lhs_src == summary.rhs_src {
+                        // TODO: there are other strings used for text now, so
                         // they will hit the second case incorrectly.
                         println!("No changes.\n");
                     } else {
@@ -550,11 +580,11 @@ fn print_diff_result(display_options: &DisplayOptions, summary: &DiffResult) {
                         &summary.rhs_display_path,
                         1,
                         1,
-                        &lang_name,
+                        &display_language,
                         display_options
                     )
                 );
-                if lang_name == "Text" {
+                if display_language == "Text" {
                     // TODO: there are other Text names now, so
                     // they will hit the second case incorrectly.
                     println!("Has changes.\n");
@@ -576,8 +606,8 @@ fn print_diff_result(display_options: &DisplayOptions, summary: &DiffResult) {
                         hunks,
                         &summary.lhs_display_path,
                         &summary.rhs_display_path,
-                        &lang_name,
-                        summary.detected_language,
+                        &display_language,
+                        summary.language_used,
                     );
                 }
                 DisplayMode::SideBySide | DisplayMode::SideBySideShowBoth => {
@@ -586,8 +616,8 @@ fn print_diff_result(display_options: &DisplayOptions, summary: &DiffResult) {
                         display_options,
                         &summary.lhs_display_path,
                         &summary.rhs_display_path,
-                        &lang_name,
-                        summary.detected_language,
+                        &display_language,
+                        summary.language_used,
                         lhs_src,
                         rhs_src,
                         &summary.lhs_positions,
