@@ -12,6 +12,9 @@ use crate::{
     parse::syntax::{AtomKind, Syntax},
 };
 
+use super::syntax;
+use super::syntax::MatchedPos;
+
 /// A language may contain certain nodes that are in other languages
 /// and should be parsed as such (e.g. HTML <script> nodes containing
 /// JavaScript). This contains how to identify such nodes, and what
@@ -131,7 +134,7 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
                 delimiter_tokens: vec![("(", ")"), ("{", "}"), ("[", "]")],
                 highlight_query: ts::Query::new(
                     language,
-                    include_str!("../../vendor/highlights/bash.scm"),
+                    include_str!("../../vendored_parsers/highlights/bash.scm"),
                 )
                 .unwrap(),
                 sub_languages: vec![],
@@ -145,7 +148,7 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
                 delimiter_tokens: vec![("(", ")"), ("{", "}"), ("[", "]")],
                 highlight_query: ts::Query::new(
                     language,
-                    include_str!("../../vendor/highlights/c.scm"),
+                    include_str!("../../vendored_parsers/highlights/c.scm"),
                 )
                 .unwrap(),
                 sub_languages: vec![],
@@ -162,8 +165,8 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
                 highlight_query: ts::Query::new(
                     language,
                     concat!(
-                        include_str!("../../vendor/highlights/c.scm"),
-                        include_str!("../../vendor/highlights/cpp.scm")
+                        include_str!("../../vendored_parsers/highlights/c.scm"),
+                        include_str!("../../vendored_parsers/highlights/cpp.scm")
                     ),
                 )
                 .unwrap(),
@@ -180,7 +183,7 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
                     .collect(),
                 highlight_query: ts::Query::new(
                     language,
-                    include_str!("../../vendor/highlights/clojure.scm"),
+                    include_str!("../../vendored_parsers/highlights/clojure.scm"),
                 )
                 .unwrap(),
                 sub_languages: vec![],
@@ -194,7 +197,7 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
                 delimiter_tokens: vec![("(", ")")].into_iter().collect(),
                 highlight_query: ts::Query::new(
                     language,
-                    include_str!("../../vendor/highlights/cmake.scm"),
+                    include_str!("../../vendored_parsers/highlights/cmake.scm"),
                 )
                 .unwrap(),
                 sub_languages: vec![],
@@ -224,7 +227,7 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
                 delimiter_tokens: vec![("{", "}"), ("(", ")")],
                 highlight_query: ts::Query::new(
                     language,
-                    include_str!("../../vendor/highlights/c-sharp.scm"),
+                    include_str!("../../vendored_parsers/highlights/c-sharp.scm"),
                 )
                 .unwrap(),
                 sub_languages: vec![],
@@ -234,11 +237,13 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
             let language = unsafe { tree_sitter_css() };
             TreeSitterConfig {
                 language,
-                atom_nodes: vec!["integer_value", "float_value"].into_iter().collect(),
+                atom_nodes: vec!["integer_value", "float_value", "color_value"]
+                    .into_iter()
+                    .collect(),
                 delimiter_tokens: vec![("{", "}"), ("(", ")")],
                 highlight_query: ts::Query::new(
                     language,
-                    include_str!("../../vendor/highlights/css.scm"),
+                    include_str!("../../vendored_parsers/highlights/css.scm"),
                 )
                 .unwrap(),
                 sub_languages: vec![],
@@ -252,7 +257,7 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
                 delimiter_tokens: vec![("{", "}"), ("(", ")"), ("[", "]"), ("<", ">")],
                 highlight_query: ts::Query::new(
                     language,
-                    include_str!("../../vendor/highlights/dart.scm"),
+                    include_str!("../../vendored_parsers/highlights/dart.scm"),
                 )
                 .unwrap(),
                 sub_languages: vec![],
@@ -268,7 +273,7 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
                     .collect(),
                 highlight_query: ts::Query::new(
                     language,
-                    include_str!("../../vendor/highlights/elisp.scm"),
+                    include_str!("../../vendored_parsers/highlights/elisp.scm"),
                 )
                 .unwrap(),
                 sub_languages: vec![],
@@ -284,7 +289,7 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
                     .collect(),
                 highlight_query: ts::Query::new(
                     language,
-                    include_str!("../../vendor/highlights/elixir.scm"),
+                    include_str!("../../vendored_parsers/highlights/elixir.scm"),
                 )
                 .unwrap(),
                 sub_languages: vec![],
@@ -298,7 +303,7 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
                 delimiter_tokens: vec![("{", "}"), ("[", "]"), ("(", ")")],
                 highlight_query: ts::Query::new(
                     language,
-                    include_str!("../../vendor/highlights/elm.scm"),
+                    include_str!("../../vendored_parsers/highlights/elm.scm"),
                 )
                 .unwrap(),
                 sub_languages: vec![],
@@ -312,7 +317,7 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
                 delimiter_tokens: vec![("{", "}"), ("(", ")"), ("[", "]"), ("|", "|")],
                 highlight_query: ts::Query::new(
                     language,
-                    include_str!("../../vendor/highlights/elvish.scm"),
+                    include_str!("../../vendored_parsers/highlights/elvish.scm"),
                 )
                 .unwrap(),
                 sub_languages: vec![],
@@ -326,7 +331,7 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
                 delimiter_tokens: vec![("(", ")"), ("{", "}"), ("[", "]")],
                 highlight_query: ts::Query::new(
                     language,
-                    include_str!("../../vendor/highlights/erlang.scm"),
+                    include_str!("../../vendored_parsers/highlights/erlang.scm"),
                 )
                 .unwrap(),
                 sub_languages: vec![],
@@ -340,7 +345,7 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
                 delimiter_tokens: vec![("(", ")"), ("[", "]"), ("{", "}")],
                 highlight_query: ts::Query::new(
                     language,
-                    include_str!("../../vendor/highlights/gleam.scm"),
+                    include_str!("../../vendored_parsers/highlights/gleam.scm"),
                 )
                 .unwrap(),
                 sub_languages: vec![],
@@ -358,7 +363,7 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
                     .collect(),
                 highlight_query: ts::Query::new(
                     language,
-                    include_str!("../../vendor/highlights/go.scm"),
+                    include_str!("../../vendored_parsers/highlights/go.scm"),
                 )
                 .unwrap(),
                 sub_languages: vec![],
@@ -372,7 +377,7 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
                 delimiter_tokens: vec![("[", "]"), ("(", ")"), ("<", ">"), ("{", "}")],
                 highlight_query: ts::Query::new(
                     language,
-                    include_str!("../../vendor/highlights/hack.scm"),
+                    include_str!("../../vendored_parsers/highlights/hack.scm"),
                 )
                 .unwrap(),
                 sub_languages: vec![],
@@ -388,7 +393,7 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
                 delimiter_tokens: vec![("[", "]"), ("(", ")"), ("{", "}")],
                 highlight_query: ts::Query::new(
                     language,
-                    include_str!("../../vendor/highlights/hare.scm"),
+                    include_str!("../../vendored_parsers/highlights/hare.scm"),
                 )
                 .unwrap(),
                 sub_languages: vec![],
@@ -402,7 +407,7 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
                 delimiter_tokens: vec![("[", "]"), ("(", ")")],
                 highlight_query: ts::Query::new(
                     language,
-                    include_str!("../../vendor/highlights/haskell.scm"),
+                    include_str!("../../vendored_parsers/highlights/haskell.scm"),
                 )
                 .unwrap(),
                 sub_languages: vec![],
@@ -423,7 +428,7 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
                 ],
                 highlight_query: ts::Query::new(
                     language,
-                    include_str!("../../vendor/highlights/hcl.scm"),
+                    include_str!("../../vendored_parsers/highlights/hcl.scm"),
                 )
                 .unwrap(),
                 sub_languages: vec![],
@@ -448,7 +453,7 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
                     .collect(),
                 highlight_query: ts::Query::new(
                     language,
-                    include_str!("../../vendor/highlights/html.scm"),
+                    include_str!("../../vendored_parsers/highlights/html.scm"),
                 )
                 .unwrap(),
                 sub_languages: vec![
@@ -482,7 +487,7 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
                 .collect(),
                 highlight_query: ts::Query::new(
                     language,
-                    include_str!("../../vendor/highlights/janet_simple.scm"),
+                    include_str!("../../vendored_parsers/highlights/janet_simple.scm"),
                 )
                 .unwrap(),
                 sub_languages: vec![],
@@ -496,7 +501,7 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
                 delimiter_tokens: vec![("(", ")"), ("{", "}"), ("[", "]")],
                 highlight_query: ts::Query::new(
                     language,
-                    include_str!("../../vendor/highlights/java.scm"),
+                    include_str!("../../vendored_parsers/highlights/java.scm"),
                 )
                 .unwrap(),
                 sub_languages: vec![],
@@ -520,7 +525,7 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
                 ],
                 highlight_query: ts::Query::new(
                     language,
-                    include_str!("../../vendor/highlights/javascript.scm"),
+                    include_str!("../../vendored_parsers/highlights/javascript.scm"),
                 )
                 .unwrap(),
                 sub_languages: vec![],
@@ -534,7 +539,7 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
                 delimiter_tokens: vec![("{", "}"), ("[", "]")],
                 highlight_query: ts::Query::new(
                     language,
-                    include_str!("../../vendor/highlights/json.scm"),
+                    include_str!("../../vendored_parsers/highlights/json.scm"),
                 )
                 .unwrap(),
                 sub_languages: vec![],
@@ -555,7 +560,7 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
                 delimiter_tokens: vec![("{", "}"), ("[", "]"), ("(", ")")],
                 highlight_query: ts::Query::new(
                     language,
-                    include_str!("../../vendor/highlights/julia.scm"),
+                    include_str!("../../vendored_parsers/highlights/julia.scm"),
                 )
                 .unwrap(),
                 sub_languages: vec![],
@@ -573,7 +578,7 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
                     .collect(),
                 highlight_query: ts::Query::new(
                     language,
-                    include_str!("../../vendor/highlights/kotlin.scm"),
+                    include_str!("../../vendored_parsers/highlights/kotlin.scm"),
                 )
                 .unwrap(),
                 sub_languages: vec![],
@@ -589,7 +594,7 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
                     .collect(),
                 highlight_query: ts::Query::new(
                     language,
-                    include_str!("../../vendor/highlights/lua.scm"),
+                    include_str!("../../vendored_parsers/highlights/lua.scm"),
                 )
                 .unwrap(),
                 sub_languages: vec![],
@@ -603,7 +608,7 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
                 delimiter_tokens: vec![("(", ")")].into_iter().collect(),
                 highlight_query: ts::Query::new(
                     language,
-                    include_str!("../../vendor/highlights/make.scm"),
+                    include_str!("../../vendored_parsers/highlights/make.scm"),
                 )
                 .unwrap(),
                 sub_languages: vec![TreeSitterSubLanguage {
@@ -623,7 +628,7 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
                 delimiter_tokens: vec![("{", "}"), ("[", "]")].into_iter().collect(),
                 highlight_query: ts::Query::new(
                     language,
-                    include_str!("../../vendor/highlights/nix.scm"),
+                    include_str!("../../vendored_parsers/highlights/nix.scm"),
                 )
                 .unwrap(),
                 sub_languages: vec![],
@@ -637,7 +642,7 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
                 delimiter_tokens: vec![("(", ")"), ("[", "]"), ("{", "}")],
                 highlight_query: ts::Query::new(
                     language,
-                    include_str!("../../vendor/highlights/ocaml.scm"),
+                    include_str!("../../vendored_parsers/highlights/ocaml.scm"),
                 )
                 .unwrap(),
                 sub_languages: vec![],
@@ -651,7 +656,7 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
                 delimiter_tokens: vec![("(", ")"), ("[", "]"), ("{", "}")],
                 highlight_query: ts::Query::new(
                     language,
-                    include_str!("../../vendor/highlights/ocaml.scm"),
+                    include_str!("../../vendored_parsers/highlights/ocaml.scm"),
                 )
                 .unwrap(),
                 sub_languages: vec![],
@@ -665,7 +670,7 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
                 delimiter_tokens: vec![("(", ")"), ("[", "]")],
                 highlight_query: ts::Query::new(
                     language,
-                    include_str!("../../vendor/highlights/pascal.scm"),
+                    include_str!("../../vendored_parsers/highlights/pascal.scm"),
                 )
                 .unwrap(),
                 sub_languages: vec![],
@@ -690,7 +695,7 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
                 delimiter_tokens: vec![("(", ")"), ("{", "}"), ("[", "]")],
                 highlight_query: ts::Query::new(
                     language,
-                    include_str!("../../vendor/highlights/perl.scm"),
+                    include_str!("../../vendored_parsers/highlights/perl.scm"),
                 )
                 .unwrap(),
                 sub_languages: vec![],
@@ -704,7 +709,7 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
                 delimiter_tokens: vec![("(", ")"), ("[", "]"), ("{", "}")],
                 highlight_query: ts::Query::new(
                     language,
-                    include_str!("../../vendor/highlights/php.scm"),
+                    include_str!("../../vendored_parsers/highlights/php.scm"),
                 )
                 .unwrap(),
                 sub_languages: vec![],
@@ -718,7 +723,7 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
                 delimiter_tokens: vec![("(", ")"), ("[", "]"), ("{", "}")],
                 highlight_query: ts::Query::new(
                     language,
-                    include_str!("../../vendor/highlights/python.scm"),
+                    include_str!("../../vendored_parsers/highlights/python.scm"),
                 )
                 .unwrap(),
                 sub_languages: vec![],
@@ -735,9 +740,9 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
                 highlight_query: ts::Query::new(
                     language,
                     concat!(
-                        include_str!("../../vendor/highlights/javascript.scm"),
-                        include_str!("../../vendor/highlights/typescript.scm"),
-                        include_str!("../../vendor/highlights/qmljs.scm"),
+                        include_str!("../../vendored_parsers/highlights/javascript.scm"),
+                        include_str!("../../vendored_parsers/highlights/typescript.scm"),
+                        include_str!("../../vendored_parsers/highlights/qmljs.scm"),
                     ),
                 )
                 .unwrap(),
@@ -762,7 +767,7 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
                 ],
                 highlight_query: ts::Query::new(
                     language,
-                    include_str!("../../vendor/highlights/ruby.scm"),
+                    include_str!("../../vendored_parsers/highlights/ruby.scm"),
                 )
                 .unwrap(),
                 sub_languages: vec![],
@@ -776,7 +781,7 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
                 delimiter_tokens: vec![("{", "}"), ("(", ")"), ("[", "]"), ("|", "|"), ("<", ">")],
                 highlight_query: ts::Query::new(
                     language,
-                    include_str!("../../vendor/highlights/rust.scm"),
+                    include_str!("../../vendored_parsers/highlights/rust.scm"),
                 )
                 .unwrap(),
                 sub_languages: vec![],
@@ -790,7 +795,7 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
                 delimiter_tokens: vec![("{", "}"), ("(", ")"), ("[", "]")],
                 highlight_query: ts::Query::new(
                     language,
-                    include_str!("../../vendor/highlights/scala.scm"),
+                    include_str!("../../vendored_parsers/highlights/scala.scm"),
                 )
                 .unwrap(),
                 sub_languages: vec![],
@@ -804,7 +809,7 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
                 delimiter_tokens: vec![("(", ")")],
                 highlight_query: ts::Query::new(
                     language,
-                    include_str!("../../vendor/highlights/sql.scm"),
+                    include_str!("../../vendored_parsers/highlights/sql.scm"),
                 )
                 .unwrap(),
                 sub_languages: vec![],
@@ -818,7 +823,7 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
                 delimiter_tokens: vec![("{", "}"), ("(", ")"), ("[", "]"), ("<", ">")],
                 highlight_query: ts::Query::new(
                     language,
-                    include_str!("../../vendor/highlights/swift.scm"),
+                    include_str!("../../vendored_parsers/highlights/swift.scm"),
                 )
                 .unwrap(),
                 sub_languages: vec![],
@@ -832,7 +837,7 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
                 delimiter_tokens: vec![("{", "}"), ("[", "]")],
                 highlight_query: ts::Query::new(
                     language,
-                    include_str!("../../vendor/highlights/toml.scm"),
+                    include_str!("../../vendored_parsers/highlights/toml.scm"),
                 )
                 .unwrap(),
                 sub_languages: vec![],
@@ -847,8 +852,8 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
                 highlight_query: ts::Query::new(
                     language,
                     concat!(
-                        include_str!("../../vendor/highlights/javascript.scm"),
-                        include_str!("../../vendor/highlights/typescript.scm"),
+                        include_str!("../../vendored_parsers/highlights/javascript.scm"),
+                        include_str!("../../vendored_parsers/highlights/typescript.scm"),
                     ),
                 )
                 .unwrap(),
@@ -866,8 +871,8 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
                 highlight_query: ts::Query::new(
                     language,
                     concat!(
-                        include_str!("../../vendor/highlights/javascript.scm"),
-                        include_str!("../../vendor/highlights/typescript.scm"),
+                        include_str!("../../vendored_parsers/highlights/javascript.scm"),
+                        include_str!("../../vendored_parsers/highlights/typescript.scm"),
                     ),
                 )
                 .unwrap(),
@@ -889,7 +894,7 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
                 delimiter_tokens: (vec![("{", "}"), ("(", ")"), ("[", "]")]),
                 highlight_query: ts::Query::new(
                     language,
-                    include_str!("../../vendor/highlights/yaml.scm"),
+                    include_str!("../../vendored_parsers/highlights/yaml.scm"),
                 )
                 .unwrap(),
                 sub_languages: vec![],
@@ -907,7 +912,7 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
                     .collect(),
                 highlight_query: ts::Query::new(
                     language,
-                    include_str!("../../vendor/highlights/zig.scm"),
+                    include_str!("../../vendored_parsers/highlights/zig.scm"),
                 )
                 .unwrap(),
                 sub_languages: vec![],
@@ -917,7 +922,7 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
 }
 
 /// Parse `src` with tree-sitter.
-pub fn parse_to_tree(src: &str, config: &TreeSitterConfig) -> tree_sitter::Tree {
+pub fn to_tree(src: &str, config: &TreeSitterConfig) -> tree_sitter::Tree {
     let mut parser = ts::Parser::new();
     parser
         .set_language(config.language)
@@ -933,7 +938,7 @@ pub fn parse_subtrees(
     src: &str,
     config: &TreeSitterConfig,
     tree: &tree_sitter::Tree,
-) -> HashMap<usize, (tree_sitter::Tree, HighlightedNodeIds)> {
+) -> HashMap<usize, (tree_sitter::Tree, TreeSitterConfig, HighlightedNodeIds)> {
     let mut subtrees = HashMap::new();
 
     for language in &config.sub_languages {
@@ -956,7 +961,7 @@ pub fn parse_subtrees(
             let tree = parser.parse(src, None).unwrap();
             let sub_highlights = tree_highlights(&tree, src, &subconfig);
 
-            subtrees.insert(node.id(), (tree, sub_highlights));
+            subtrees.insert(node.id(), (tree, subconfig, sub_highlights));
         }
     }
 
@@ -1087,11 +1092,34 @@ fn print_cursor(src: &str, cursor: &mut ts::TreeCursor, depth: usize) {
     }
 }
 
-/// Parse `src` with tree-sitter and convert to difftastic Syntax.
-pub fn parse<'a>(
-    arena: &'a Arena<Syntax<'a>>,
+pub fn comment_positions(
+    tree: &tree_sitter::Tree,
     src: &str,
     config: &TreeSitterConfig,
+) -> Vec<MatchedPos> {
+    let arena = Arena::new();
+    let ignore_comments = false;
+
+    let nodes = to_syntax(&tree, src, &arena, config, ignore_comments);
+    let positions = syntax::comment_positions(&nodes);
+
+    positions
+        .into_iter()
+        .map(|pos| MatchedPos {
+            kind: syntax::MatchKind::Ignored {
+                highlight: syntax::TokenKind::Atom(AtomKind::Comment),
+            },
+            pos,
+        })
+        .collect()
+}
+
+pub fn to_syntax<'a>(
+    tree: &tree_sitter::Tree,
+    src: &str,
+    arena: &'a Arena<Syntax<'a>>,
+    config: &TreeSitterConfig,
+    ignore_comments: bool,
 ) -> Vec<&'a Syntax<'a>> {
     // Don't return anything on an empty input. Most parsers return a
     // zero-width top-level AST node on empty files, which is
@@ -1100,7 +1128,6 @@ pub fn parse<'a>(
         return vec![];
     }
 
-    let tree = parse_to_tree(src, config);
     let highlights = tree_highlights(&tree, src, config);
 
     // Parse sub-languages, if any, which will be used both for
@@ -1122,9 +1149,21 @@ pub fn parse<'a>(
         config,
         &highlights,
         &subtrees,
+        ignore_comments,
     )
 }
 
+/// Parse `src` with tree-sitter and convert to difftastic Syntax.
+pub fn parse<'a>(
+    arena: &'a Arena<Syntax<'a>>,
+    src: &str,
+    config: &TreeSitterConfig,
+    ignore_comments: bool,
+) -> Vec<&'a Syntax<'a>> {
+    let tree = to_tree(src, config);
+    to_syntax(&tree, src, arena, config, ignore_comments)
+}
+
 fn child_tokens<'a>(src: &'a str, cursor: &mut ts::TreeCursor) -> Vec<Option<&'a str>> {
     let mut tokens = vec![];
 
@@ -1191,13 +1230,21 @@ fn all_syntaxes_from_cursor<'a>(
     cursor: &mut ts::TreeCursor,
     config: &TreeSitterConfig,
     highlights: &HighlightedNodeIds,
-    subtrees: &HashMap<usize, (tree_sitter::Tree, HighlightedNodeIds)>,
+    subtrees: &HashMap<usize, (tree_sitter::Tree, TreeSitterConfig, HighlightedNodeIds)>,
+    ignore_comments: bool,
 ) -> Vec<&'a Syntax<'a>> {
     let mut result: Vec<&Syntax> = vec![];
 
     loop {
         result.extend(syntax_from_cursor(
-            arena, src, nl_pos, cursor, config, highlights, subtrees,
+            arena,
+            src,
+            nl_pos,
+            cursor,
+            config,
+            highlights,
+            subtrees,
+            ignore_comments,
         ));
 
         if !cursor.goto_next_sibling() {
@@ -1217,21 +1264,23 @@ fn syntax_from_cursor<'a>(
     cursor: &mut ts::TreeCursor,
     config: &TreeSitterConfig,
     highlights: &HighlightedNodeIds,
-    subtrees: &HashMap<usize, (tree_sitter::Tree, HighlightedNodeIds)>,
+    subtrees: &HashMap<usize, (tree_sitter::Tree, TreeSitterConfig, HighlightedNodeIds)>,
+    ignore_comments: bool,
 ) -> Option<&'a Syntax<'a>> {
     let node = cursor.node();
 
     // See if we should go into a sub-document instead (e.g. embedded JavaScript in HTML).
-    if let Some((subtree, subhighlights)) = subtrees.get(&node.id()) {
+    if let Some((subtree, subconfig, subhighlights)) = subtrees.get(&node.id()) {
         let mut sub_cursor = subtree.walk();
         return syntax_from_cursor(
             arena,
             src,
             nl_pos,
             &mut sub_cursor,
-            config,
+            subconfig,
             subhighlights,
             &HashMap::new(),
+            ignore_comments,
         );
     }
 
@@ -1245,17 +1294,24 @@ fn syntax_from_cursor<'a>(
         );
 
         // Treat error nodes as atoms, even if they have children.
-        atom_from_cursor(arena, src, nl_pos, cursor, highlights)
+        atom_from_cursor(arena, src, nl_pos, cursor, highlights, ignore_comments)
     } else if config.atom_nodes.contains(node.kind()) {
         // Treat nodes like string literals as atoms, regardless
         // of whether they have children.
-        atom_from_cursor(arena, src, nl_pos, cursor, highlights)
+        atom_from_cursor(arena, src, nl_pos, cursor, highlights, ignore_comments)
     } else if node.child_count() > 0 {
         Some(list_from_cursor(
-            arena, src, nl_pos, cursor, config, highlights, subtrees,
+            arena,
+            src,
+            nl_pos,
+            cursor,
+            config,
+            highlights,
+            subtrees,
+            ignore_comments,
         ))
     } else {
-        atom_from_cursor(arena, src, nl_pos, cursor, highlights)
+        atom_from_cursor(arena, src, nl_pos, cursor, highlights, ignore_comments)
     }
 }
 
@@ -1268,7 +1324,8 @@ fn list_from_cursor<'a>(
     cursor: &mut ts::TreeCursor,
     config: &TreeSitterConfig,
     highlights: &HighlightedNodeIds,
-    subtrees: &HashMap<usize, (tree_sitter::Tree, HighlightedNodeIds)>,
+    subtrees: &HashMap<usize, (tree_sitter::Tree, TreeSitterConfig, HighlightedNodeIds)>,
+    ignore_comments: bool,
 ) -> &'a Syntax<'a> {
     let root_node = cursor.node();
 
@@ -1312,21 +1369,42 @@ fn list_from_cursor<'a>(
         let node = cursor.node();
         if node_i < i {
             before_delim.extend(syntax_from_cursor(
-                arena, src, nl_pos, cursor, config, highlights, subtrees,
+                arena,
+                src,
+                nl_pos,
+                cursor,
+                config,
+                highlights,
+                subtrees,
+                ignore_comments,
             ));
         } else if node_i == i {
             inner_open_content = &src[node.start_byte()..node.end_byte()];
             inner_open_position = nl_pos.from_offsets(node.start_byte(), node.end_byte());
         } else if node_i < j {
             between_delim.extend(syntax_from_cursor(
-                arena, src, nl_pos, cursor, config, highlights, subtrees,
+                arena,
+                src,
+                nl_pos,
+                cursor,
+                config,
+                highlights,
+                subtrees,
+                ignore_comments,
             ));
         } else if node_i == j {
             inner_close_content = &src[node.start_byte()..node.end_byte()];
             inner_close_position = nl_pos.from_offsets(node.start_byte(), node.end_byte());
         } else if node_i > j {
             after_delim.extend(syntax_from_cursor(
-                arena, src, nl_pos, cursor, config, highlights, subtrees,
+                arena,
+                src,
+                nl_pos,
+                cursor,
+                config,
+                highlights,
+                subtrees,
+                ignore_comments,
             ));
         }
 
@@ -1378,6 +1456,7 @@ fn atom_from_cursor<'a>(
     nl_pos: &NewlinePositions,
     cursor: &mut ts::TreeCursor,
     highlights: &HighlightedNodeIds,
+    ignore_comments: bool,
 ) -> Option<&'a Syntax<'a>> {
     let node = cursor.node();
     let position = nl_pos.from_offsets(node.start_byte(), node.end_byte());
@@ -1410,6 +1489,11 @@ fn atom_from_cursor<'a>(
         // 'comment' as their comment node name, but if they don't we
         // can still detect comments by looking at their syntax
         // highlighting.
+
+        if ignore_comments {
+            return None;
+        }
+
         AtomKind::Comment
     } else if highlights.keyword_ids.contains(&node.id()) {
         AtomKind::Keyword
@@ -1435,14 +1519,14 @@ mod tests {
     fn test_parse() {
         let arena = Arena::new();
         let css_config = from_language(guess::Language::Css);
-        parse(&arena, ".foo {}", &css_config);
+        parse(&arena, ".foo {}", &css_config, false);
     }
 
     #[test]
     fn test_parse_empty_file() {
         let arena = Arena::new();
         let config = from_language(guess::Language::EmacsLisp);
-        let res = parse(&arena, "", &config);
+        let res = parse(&arena, "", &config, false);
 
         let expected: Vec<&Syntax> = vec![];
         assert_eq!(res, expected);
@@ -1454,7 +1538,7 @@ mod tests {
     fn test_subtrees() {
         let arena = Arena::new();
         let config = from_language(guess::Language::Html);
-        let res = parse(&arena, "<style>.a { color: red; }</style>", &config);
+        let res = parse(&arena, "<style>.a { color: red; }</style>", &config, false);
 
         match res[0] {
             Syntax::List {
